Imports Microsoft.VisualStudio.TestTools.UnitTesting
Imports SSIS.Test
Imports SSIS.Test.Metadata
Imports System.IO

Namespace MySsisUnitTests.LiveTests
	<ActionClass("CUSTOMERS", "CopyCustomers.dtsx")>
	Public Class CopyCustomers
		Inherits BaseLiveTest

		Public Sub New()
			MyBase.New()
			' reset the environment to allow this to be runnable
			If File.Exists(Constants.CustomersFileDestination) Then
				File.Delete(Constants.CustomersFileDestination)
			End If

			If File.Exists(Constants.CustomersFileConverted) Then
				File.Delete(Constants.CustomersFileConverted)
			End If
		End Sub

		<ActionMethod("\[CopyCustomers]")>
		Public Sub TestWholePackage(ByVal context As ActionContext)
			' check if the package executed successfully
			Assert.AreEqual(True, context.Package.IsExecutionSuccess)
		End Sub

		<ActionMethod("\[CopyCustomers]\[FST Copy Source File]")>
		Public Sub TestCopySourceFile(ByVal context As ActionContext)
			' check if the task "FST Copy Source File" executed successfully and if the file has been copied
			Assert.AreEqual(True, context.ActiveExecutable.IsExecutionSuccess)
			Assert.AreEqual(True, File.Exists(Constants.CustomersFileDestination))
		End Sub

		<ActionMethod("\[CopyCustomers]\[DFT Convert customer names]")>
		Public Sub TestConvertCustomerNames(ByVal context As ActionContext)
			' check if the task "DFT Convert customer names" executed successfully and if the names have been upper cased
			Assert.AreEqual(True, context.ActiveExecutable.IsExecutionSuccess)
			Dim lines() As String = File.ReadAllLines(Constants.CustomersFileConverted)
			Assert.AreEqual("COMPANY2", lines(2).Split(","c)(1))
		End Sub
	End Class
End Namespace
