Imports Microsoft.VisualStudio.TestTools.UnitTesting
Imports SSIS.Test
Imports SSIS.Test.Dts
Imports SSIS.Test.Metadata

Namespace MySsisUnitTests.LiveTests
	 <ActionClass("CUSTOMERS", "LoadCustomers.dtsx")>
	 Public Class LoadCustomers
		 Inherits BaseLiveTest

		<ActionMethod("\[LoadCustomers]")>
		Public Sub TestWholePackage(ByVal context As ActionContext)
			' check if the package executed successfully
			Assert.AreEqual(True, context.Package.IsExecutionSuccess)

			' check package variable - it should equals 3 since we have 3 customers in the input file
			Dim variable As DtsVariable = context.Package.GetVariableForPath("\[LoadCustomers].[CustomerCount]")
			Dim countInsert As Integer = CInt(Fix(variable.GetValue))

			Assert.AreEqual(3, countInsert)
		End Sub

		<ActionMethod("\[LoadCustomers]\[SEQC Load]\[DFT Load customers]")>
		Public Sub TestLoadCustomers(ByVal context As ActionContext)
			' check if the task "DFT Load customers" executed successfully
			Assert.AreEqual(True, context.ActiveExecutable.IsExecutionSuccess)

			' check the target table - it should contain 3 customers from the input file
			context.DataAccess.OpenConnection(Constants.DbConnectionString)
			Dim rowCount As Integer = CInt(Fix(context.DataAccess.ExecuteScalar("select count(*) from [dbo].[CustomersStaging]")))
			context.DataAccess.CloseConnection()

			Assert.AreEqual(3, rowCount)
		End Sub

		<ActionMethod("\[LoadCustomers]\[SEQC Load]\[SQL Truncate CustomersStaging]")>
		Public Sub TestTruncateCustomerStaging(ByVal context As ActionContext)
			' check if the task "SQL Truncate CustomersStaging" executed successfully
			Assert.AreEqual(True, context.ActiveExecutable.IsExecutionSuccess)

			' check the target table - it should contain no data after truncate
			context.DataAccess.OpenConnection(Constants.DbConnectionString)
			Dim rowCount As Integer = CInt(Fix(context.DataAccess.ExecuteScalar("select count(*) from [dbo].[CustomersStaging]")))
			context.DataAccess.CloseConnection()

			Assert.AreEqual(0, rowCount)
		End Sub
	 End Class
End Namespace
