Imports SSIS.Test
Imports SSIS.Test.Report

Namespace MySsisUnitTests
	Friend Class Program
		<STAThread>
		Shared Sub Main(ByVal args() As String)
			RunUnitTests()
			' to run live tests, comment the RunUnitTests and uncomment the RunLiveTests
			'RunLiveTests();

			If Debugger.IsAttached Then
				Debugger.Break()
			End If
		End Sub

		''' <summary>
		''' Executes demo unit tests.
		''' </summary>
		Private Shared Sub RunUnitTests()
			' create engine for unit testing
			Dim engine As IUnitTestEngine = EngineFactory.GetClassInstance(Of IUnitTestEngine)()

			' load packages and relate them to the logical group - repository
			engine.LoadPackages("CUSTOMERS", Constants.PathToPackages)

			' load unit tests from the current assembly
			engine.LoadRepositoryUnitTests("CUSTOMERS")

			' execute unit tests
			engine.ExecuteUnitTestsWithGui()
		End Sub

		''' <summary>
		''' Executes demo live tests.
		''' </summary>
		Private Shared Sub RunLiveTests()
			' set package execution parameters eg. variables, connections
			Dim parameters = New ExecutionParameters

			' add variables and their values to be set when the package has been loaded
			parameters.AddVariable("\[Main].[ConnectionString]", Constants.SsisDbConnectionString)
			parameters.AddVariable("\[Main].[CopyCustomersPath]", Constants.PathToCopyCustomersPackage)
			parameters.AddVariable("\[Main].[LoadCustomersPath]", Constants.PathToLoadCustomersPackage)
			parameters.AddVariable("\[Main].[ConvertDestinationPath]", Constants.CustomersFileConverted)
			parameters.AddVariable("\[Main].[DestinationPath]", Constants.CustomersFileDestination)
			parameters.AddVariable("\[Main].[SourcePath]", Constants.CustomersFileSource)

			' create engine for live testing
			Dim engine As ILiveTestEngine = EngineFactory.GetClassInstance(Of ILiveTestEngine)()

			' load packages and relate them to the logical group - repository
			engine.LoadPackages("CUSTOMERS", Constants.PathToPackages)

			' load live tests from the current assembly
			engine.LoadRepositoryActions("CUSTOMERS")

			' set execution parameters
			engine.SetExecutionParameters(parameters)

			' execute the package and attach live tests
			engine.ExecuteLiveTestsWithGui("CUSTOMERS", "Main.dtsx")
		End Sub
	End Class
End Namespace
