Imports Microsoft.VisualStudio.TestTools.UnitTesting
Imports SSIS.Test
Imports SSIS.Test.Dts
Imports SSIS.Test.Metadata
Imports System.IO

Namespace MySsisUnitTests.UnitTests
	<UnitTest("CUSTOMERS", "CopyCustomers.dtsx")>
	Public Class CopyCustomersTest
		Inherits BaseUnitTest

		Protected Overrides Sub Setup(ByVal context As SetupContext)
			' clean up previous executions
			If File.Exists(Constants.CustomersFileDestination) Then
				File.Delete(Constants.CustomersFileDestination)
			End If

			If File.Exists(Constants.CustomersFileConverted) Then
				File.Delete(Constants.CustomersFileConverted)
			End If

			' set package variables to the correct paths
			Dim sourceFile As DtsVariable = context.Package.GetVariable("SourcePath")
			sourceFile.SetValue(Constants.CustomersFileSource)

			Dim destinationFile As DtsVariable = context.Package.GetVariable("DestinationPath")
			destinationFile.SetValue(Constants.CustomersFileDestination)

			Dim convertedFile As DtsVariable = context.Package.GetVariable("ConvertDestinationPath")
			convertedFile.SetValue(Constants.CustomersFileConverted)
		End Sub

		Protected Overrides Sub Verify(ByVal context As VerificationContext)
			' check if package executed and if all files are copied
			Assert.AreEqual(True, context.Package.IsExecutionSuccess)
			Assert.AreEqual(True, File.Exists(Constants.CustomersFileDestination))
			Assert.AreEqual(True, File.Exists(Constants.CustomersFileConverted))
			Dim lines() As String = File.ReadAllLines(Constants.CustomersFileConverted)
			Assert.AreEqual("COMPANY2", lines(2).Split(","c)(1))
		End Sub

		Protected Overrides Sub Teardown(ByVal context As TeardownContext)
			' delete all files that were used for this unit test
			File.Delete(Constants.CustomersFileDestination)
			File.Delete(Constants.CustomersFileConverted)
		End Sub
	End Class
End Namespace
