Imports Microsoft.VisualStudio.TestTools.UnitTesting
Imports SSIS.Test
Imports SSIS.Test.Dts
Imports SSIS.Test.Metadata
Imports System.IO

Namespace MySsisUnitTests.UnitTests
	<UnitTest("CUSTOMERS", "LoadCustomers.dtsx", ExecutableName := "\[LoadCustomers]\[SEQC Load]\[DFT Load customers]")>
	Friend Class LoadCustomersTest
		Inherits BaseUnitTest

		Protected Overrides Sub Setup(ByVal context As SetupContext)
			' reset the environment to allow this to be runnable
			If File.Exists(Constants.CustomersFileDestination) Then
				File.Delete(Constants.CustomersFileDestination)
			End If

			If File.Exists(Constants.CustomersFileConverted) Then
				File.Delete(Constants.CustomersFileConverted)
			End If

			' copy the source file needed by the data flow
			File.Copy(Constants.CustomersFileSource, Constants.CustomersFileDestination)

			' truncate the target table
			context.DataAccess.OpenConnection(Constants.DbConnectionString)
			context.DataAccess.ExecuteNonQuery("truncate table [dbo].[CustomersStaging]")
			context.DataAccess.CloseConnection()

			' set connection strings
			Dim conn As DtsConnection = context.Package.GetConnection("CustomerDB")
			conn.SetConnectionString(Constants.SsisDbConnectionString)

			conn = context.Package.GetConnection("Customers Src")
			conn.SetConnectionString(Constants.CustomersFileDestination)
		End Sub

		Protected Overrides Sub Verify(ByVal context As VerificationContext)
			' check if package and target task executed
			Assert.AreEqual(True, context.Package.IsExecutionSuccess)
			Assert.AreEqual(True, context.ActiveExecutable.IsExecutionSuccess)

			' check number of customers in the target table - it should be 3 since we have 3 in the source file
			context.DataAccess.OpenConnection(Constants.DbConnectionString)
			Dim rowCount As Integer = CInt(Fix(context.DataAccess.ExecuteScalar("select count(*) from [dbo].[CustomersStaging]")))
			context.DataAccess.CloseConnection()

			Assert.AreEqual(3, rowCount)
		End Sub

		Protected Overrides Sub Teardown(ByVal context As TeardownContext)
			' clean up - delete all used files and truncate table
			File.Delete(Constants.CustomersFileDestination)
			context.DataAccess.OpenConnection(Constants.DbConnectionString)
			context.DataAccess.ExecuteNonQuery("truncate table [dbo].[CustomersStaging]")
			context.DataAccess.CloseConnection()
		End Sub
	End Class
End Namespace
